@@ -4,9 +4,7 @@ from abc import abstractmethod, ABC
 from typing import Tuple, TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from nrel.hive.state.simulation_state.simulation_state import (
-        SimulationState,
-    )
+    from nrel.hive.state.simulation_state.simulation_state import SimulationState
 
 from nrel.hive.dispatcher.forecaster.forecast import Forecast
 
