@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import NamedTuple, TYPE_CHECKING, FrozenSet
+from typing import NamedTuple, TYPE_CHECKING, FrozenSet, Optional
 
 from nrel.hive.reporting.reporter import Reporter
 
@@ -8,16 +8,13 @@ import immutables
 
 if TYPE_CHECKING:
     from nrel.hive.model.energy.charger.charger import Charger
-    from nrel.hive.model.vehicle.mechatronics.mechatronics_interface import (
-        MechatronicsInterface,
-    )
+    from nrel.hive.model.vehicle.mechatronics.mechatronics_interface import MechatronicsInterface
     from nrel.hive.config import HiveConfig
+    from nrel.hive.model.vehicle.schedules.schedule import ScheduleFunction
     from nrel.hive.util.typealiases import (
         ChargerId,
         MechatronicsId,
         MembershipId,
-        MembershipMap,
-        ScheduleFunction,
         ScheduleId,
     )
 
@@ -32,7 +29,7 @@ class Environment(NamedTuple):
     mechatronics: immutables.Map[MechatronicsId, MechatronicsInterface] = immutables.Map()
     chargers: immutables.Map[ChargerId, Charger] = immutables.Map()
     schedules: immutables.Map[ScheduleId, ScheduleFunction] = immutables.Map()
-    fleet_ids: FrozenSet[MembershipId] = frozenset()
+    fleet_ids: FrozenSet[Optional[MembershipId]] = frozenset()
 
     reporter: Reporter = Reporter()
 
